@@ -1,5 +1,5 @@
 from PIL import Image
-from digitalguide.telegram.special_actions.imageActions import overlay_images
+from digitalguide.special_actions.imageActions import overlay_images
 import pytest
 
 @pytest.mark.parametrize("ratio", [
